4.7. umbra.components.addons.traceUi.nodes — Umbra 1.0.4 documentation

### Navigation

- index
- modules |
- next |
- previous |
- Umbra 1.0.4 documentation »
- 4. Api »

# 4.7. umbra.components.addons.traceUi.nodes

nodes.py

Platform:
  Windows, Linux, Mac Os X.
Description:
  This module defines the `umbra.components.factory.traceUi.traceUi.TraceUi` Component Interface class nodes.

Others:

## 4.7.1. Module Attributes

`umbra.components.addons.traceUi.nodes.` `LOGGER`

## 4.7.2. Classes

class `umbra.components.addons.traceUi.nodes.` `ModuleNode`(module=None, name=None, parent=None, children=None, roles=None, nodeFlags=33, attributesFlags=33, **kwargs)

  Bases: `umbra.ui.nodes.GraphModelNode`

  This class factory defines `umbra.components.factory.traceUi.traceUi.TraceUi` Component Interface class Module node.

  Parameters: | module – Module. ( Module ) name – Node name. ( String ) parent – Node parent. ( GraphModelNode ) children – Children. ( List ) roles – Roles. ( Dictionary ) nodeFlags – Node flags. ( Integer ) attributesFlags – Attributes flags. ( Integer ) **kwargs – Keywords arguments. ( ** )

  `module`

    This method is the property for self.__module attribute.

    Returns: | self.__module. ( Object )

  `updateNodeAttributes`(attributesFlags=33)

    This method updates the Node attributes.

    Parameters: | attributesFlags – Attributes flags. ( Integer )
    Returns: | Method success. ( Boolean )

### Navigation

- index
- modules |
- next |
- previous |
- Umbra 1.0.4 documentation »
- 4. Api »